@@ -1,7 +1,7 @@
 /*
  * Copyright © 1998, 2003 Jonathan Blandford <jrb@alum.mit.edu>
  * Copyright © 2003 Callum McKenzie <callum@physics.otago.ac.nz>
- * Copyright © 2007, 2008, 2009 Christian Persch
+ * Copyright © 2007, 2008, 2009, 2010 Christian Persch
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,10 +37,9 @@
 #endif
 #endif /* HAVE_HILDON */
 
-#include <libgames-support/games-card-theme.h>
-#include <libgames-support/games-card-themes.h>
 #include <libgames-support/games-clock.h>
 #include <libgames-support/games-debug.h>
+#include <libgames-support/games-glib-compat.h>
 #include <libgames-support/games-stock.h>
 #include <libgames-support/games-runtime.h>
 #include <libgames-support/games-sound.h>
@@ -59,6 +58,8 @@
 #include "board-noclutter.h"
 #endif
 
+#include "ar-card-theme.h"
+#include "ar-card-themes.h"
 #include "conf.h"
 #include "game.h"
 #include "stats-dialog.h"
@@ -68,6 +69,10 @@
 
 #include "window.h"
 
+#ifdef ENABLE_DEBUG_UI
+#include "prop-editor.h"
+#endif
+
 #define AISLERIOT_WINDOW_GET_PRIVATE(window)(G_TYPE_INSTANCE_GET_PRIVATE ((window), AISLERIOT_TYPE_WINDOW, AisleriotWindowPrivate))
 
 #define MIN_WIDTH 600
@@ -104,9 +109,6 @@
 #define LEAVE_FULLSCREEN_BUTTON
 #endif
 
-/* define this to enable a debug menu */
-/* #undef ENABLE_DEBUG_UI */
-
 enum
 {
   ACTION_UNDO_MOVE,
@@ -129,17 +131,17 @@ enum
 struct _AisleriotWindowPrivate
 {
   AisleriotGame *game;
+  ArStyle *board_style;
 #ifdef HAVE_CLUTTER
   ArClutterEmbed *board;
-  ArStyle *board_style;
   ClutterActor *baize_actor;
   ClutterActor *board_actor;
 #else
   AisleriotBoard *board;
 #endif
 
-  GamesCardThemes *theme_manager;
-  GamesCardTheme *theme;
+  ArCardThemes *theme_manager;
+  ArCardTheme *theme;
 
 #ifdef HAVE_HILDON
   guint game_message_hash;
@@ -149,6 +151,7 @@ struct _AisleriotWindowPrivate
 #else
   GtkStatusbar *statusbar;
   guint game_message_id;
+  guint board_message_id;
   GtkWidget *score_box;
   GtkWidget *score_label;
   GtkWidget *clock;
@@ -183,10 +186,6 @@ struct _AisleriotWindowPrivate
 
   guint load_idle_id;
 
-#ifndef HAVE_CLUTTER
-  guint use_pixbuf_drawing : 1;
-#endif
-
   guint changing_game_type : 1;
   guint freecell_mode : 1;
   guint toolbar_visible : 1;
@@ -481,7 +480,7 @@ help_about_cb (GtkAction *action,
 			     "AisleRiot is a part of GNOME Games."),
 #endif
                          "copyright", "Copyright © 1998-2006 Jonathan Blandford\n"
-                                      "Copyright © 2007, 2008, 2009 Christian Persch",
+                                      "Copyright © 2007, 2008, 2009, 2010 Christian Persch",
                          "license", licence,
                          "authors", authors,
                          "artists", artists,
@@ -580,7 +579,7 @@ install_themes_cb (GtkAction *action,
 {
   AisleriotWindowPrivate *priv = window->priv;
 
-  games_card_themes_install_themes (priv->theme_manager,
+  ar_card_themes_install_themes (priv->theme_manager,
                                     GTK_WINDOW (window),
                                     gtk_get_current_event_time ());
 }
@@ -624,12 +623,7 @@ static void
 delayed_move_to_next_screen_cb (GtkAction *action,
                                 GtkWidget *widget)
 {
-#if GLIB_CHECK_VERSION (2, 14, 0)
   g_timeout_add_seconds (10, (GSourceFunc) delayed_move_to_next_screen_timeout_cb, widget);
-#else
-  g_timeout_add (10 * 1000, (GSourceFunc) delayed_move_to_next_screen_timeout_cb, widget);
-#endif /* GLIB 2.14.0 */
-
 }
 
 static void
@@ -856,18 +850,24 @@ debug_choose_seed_cb (GtkAction *action,
   gtk_window_present (GTK_WINDOW (dialog));
 }
 
-#ifndef HAVE_CLUTTER
 static void
-debug_pixbuf_drawing_cb (GtkToggleAction *action,
-                         AisleriotWindow *window)
+debug_tweak_cb (GtkAction *action,
+                AisleriotWindow *window)
 {
   AisleriotWindowPrivate *priv = window->priv;
-  gboolean active;
+  GObject *object;
+  GType type;
+  GtkWidget *prop_editor;
 
-  active = gtk_toggle_action_get_active (action);
-  aisleriot_board_set_pixbuf_drawing (priv->board, active);
+  object = G_OBJECT (priv->board_style);
+  type = G_OBJECT_TYPE (object);
+
+  g_assert (object != NULL);
+
+  prop_editor = create_prop_editor (object, type);
+  gtk_window_set_transient_for (GTK_WINDOW (prop_editor), GTK_WINDOW (window));
+  gtk_window_present (GTK_WINDOW (prop_editor));
 }
-#endif /* !HAVE_CLUTTER */
 
 #endif /* ENABLE_DEBUG_UI */
 
@@ -998,11 +998,7 @@ clickmove_toggle_cb (GtkToggleAction *action,
   click_to_move = gtk_toggle_action_get_active (action);
 
   aisleriot_game_set_click_to_move (priv->game, click_to_move);
-#ifdef HAVE_CLUTTER
   ar_style_set_click_to_move (priv->board_style, click_to_move);
-#else
-  aisleriot_board_set_click_to_move (priv->board, click_to_move);
-#endif
   
   games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_CLICK_TO_MOVE), click_to_move);
 }
@@ -1035,11 +1031,7 @@ animations_toggle_cb (GtkToggleAction *action,
 
   enabled = gtk_toggle_action_get_active (action);
 
-#ifdef HAVE_CLUTTER
   ar_style_set_enable_animations (priv->board_style, enabled);
-#else
-  aisleriot_board_set_animation_mode (priv->board, enabled);
-#endif
   
   games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_ANIMATIONS), enabled);
 }
@@ -1399,7 +1391,7 @@ install_recently_played_menu (AisleriotWindow *window)
 
 static void
 aisleriot_window_take_card_theme (AisleriotWindow *window,
-                                  GamesCardTheme *theme /* adopting */)
+                                  ArCardTheme *theme /* adopting */)
 {
   AisleriotWindowPrivate *priv = window->priv;
 #if GTK_CHECK_VERSION (2, 10, 0)
@@ -1419,15 +1411,11 @@ aisleriot_window_take_card_theme (AisleriotWindow *window,
     const cairo_font_options_t *font_options;
 
     font_options = gdk_screen_get_font_options (gtk_widget_get_screen (widget));
-    games_card_theme_set_font_options (theme, font_options);
+    ar_card_theme_set_font_options (theme, font_options);
   }
 #endif /* GTK+ 2.10.0 */
 
-#ifdef HAVE_CLUTTER
   ar_style_set_card_theme (priv->board_style, theme);
-#else
-  aisleriot_board_set_card_theme (priv->board, theme);
-#endif
 }    
 
 static void
@@ -1435,8 +1423,8 @@ card_theme_changed_cb (GtkToggleAction *action,
                        AisleriotWindow *window)
 {
   AisleriotWindowPrivate *priv = window->priv;
-  GamesCardThemeInfo *current_theme_info = NULL, *new_theme_info;
-  GamesCardTheme *theme;
+  ArCardThemeInfo *current_theme_info = NULL, *new_theme_info;
+  ArCardTheme *theme;
   const char *theme_name;
 
   if (!gtk_toggle_action_get_active (action))
@@ -1446,13 +1434,13 @@ card_theme_changed_cb (GtkToggleAction *action,
   g_assert (new_theme_info != NULL);
 
   if (priv->theme) {
-    current_theme_info = games_card_theme_get_theme_info (priv->theme);
+    current_theme_info = ar_card_theme_get_theme_info (priv->theme);
   }
 
-  if (games_card_theme_info_equal (new_theme_info, current_theme_info))
+  if (ar_card_theme_info_equal (new_theme_info, current_theme_info))
     return;
 
-  theme = games_card_themes_get_theme (priv->theme_manager, new_theme_info);
+  theme = ar_card_themes_get_theme (priv->theme_manager, new_theme_info);
   if (!theme) {
     GSList *group, *l;
 
@@ -1467,13 +1455,13 @@ card_theme_changed_cb (GtkToggleAction *action,
     group = gtk_radio_action_get_group (GTK_RADIO_ACTION (action));
     for (l = group; l != NULL; l = l->next) {
       GtkToggleAction *theme_action = GTK_TOGGLE_ACTION (l->data);
-      GamesCardThemeInfo *info;
+      ArCardThemeInfo *info;
 
       if (theme_action == action)
         continue;
 
       info = g_object_get_data (G_OBJECT (theme_action), "theme-info");
-      if (!games_card_theme_info_equal (info, current_theme_info))
+      if (!ar_card_theme_info_equal (info, current_theme_info))
         continue;
 
       /* The check at the top will prevent an infinite loop */
@@ -1486,18 +1474,18 @@ card_theme_changed_cb (GtkToggleAction *action,
 
   aisleriot_window_take_card_theme (window, theme);
 
-  theme_name = games_card_theme_info_get_persistent_name (new_theme_info);
+  theme_name = ar_card_theme_info_get_persistent_name (new_theme_info);
   games_conf_set_string (NULL, aisleriot_conf_get_key (CONF_THEME), theme_name);
 }
 
 static void
-install_card_theme_menu (GamesCardThemes *theme_manager,
+install_card_theme_menu (ArCardThemes *theme_manager,
                          AisleriotWindow *window)
 {
   AisleriotWindowPrivate *priv = window->priv;
   GList *list, *l;
   GSList *radio_group = NULL;
-  GamesCardThemeInfo *current_theme_info;
+  ArCardThemeInfo *current_theme_info;
   guint i = 0;
 
   /* Clean out the old menu */
@@ -1513,11 +1501,11 @@ install_card_theme_menu (GamesCardThemes *theme_manager,
   /* See gtk bug #424448 */
   gtk_ui_manager_ensure_update (priv->ui_manager);
 
-  list = games_card_themes_get_themes (priv->theme_manager);
+  list = ar_card_themes_get_themes (priv->theme_manager);
 
   /* No need to install the menu when there's only one theme available anyway */
   if (list == NULL || list->next == NULL) {
-    g_list_foreach (list, (GFunc) games_card_theme_info_unref, NULL);
+    g_list_foreach (list, (GFunc) ar_card_theme_info_unref, NULL);
     g_list_free (list);
     return;
   }
@@ -1529,18 +1517,18 @@ install_card_theme_menu (GamesCardThemes *theme_manager,
   priv->card_themes_merge_id = gtk_ui_manager_new_merge_id (priv->ui_manager);
 
   if (priv->theme) {
-    current_theme_info = games_card_theme_get_theme_info (priv->theme);
+    current_theme_info = ar_card_theme_get_theme_info (priv->theme);
   } else {
     current_theme_info = NULL;
   }
 
   for (l = list; l != NULL; l = l->next) {
-    GamesCardThemeInfo *info = (GamesCardThemeInfo *) l->data;
+    ArCardThemeInfo *info = (ArCardThemeInfo *) l->data;
     GtkRadioAction *action;
     char actionname[32];
     char *display_name, *tooltip;
 
-    display_name = g_strdup (games_card_theme_info_get_display_name (info));
+    display_name = g_strdup (ar_card_theme_info_get_display_name (info));
 
     g_snprintf (actionname, sizeof (actionname), "Theme%d", i);
 #ifdef HAVE_HILDON
@@ -1556,13 +1544,13 @@ install_card_theme_menu (GamesCardThemes *theme_manager,
     radio_group = gtk_radio_action_get_group (action);
 
     /* Check if this is the current theme's action. Do this before connecting the callback */
-    if (games_card_theme_info_equal (info, current_theme_info)) {
+    if (ar_card_theme_info_equal (info, current_theme_info)) {
       gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), TRUE);
     }
 
     /* We steal the data from the list */
     g_object_set_data_full (G_OBJECT (action), "theme-info",
-                            l->data, (GDestroyNotify) games_card_theme_info_unref);
+                            l->data, (GDestroyNotify) ar_card_theme_info_unref);
     l->data = NULL;
 
     g_signal_connect (action, "toggled",
@@ -1598,7 +1586,7 @@ view_menu_activate_cb (GtkAction *action,
   /* Request the list of themes. If it wasn't updated yet, the "changed"
    * callback will build the card themes submenu.
    */
-  games_card_themes_request_themes (priv->theme_manager);
+  ar_card_themes_request_themes (priv->theme_manager);
 }
 
 /* Callbacks */
@@ -1775,6 +1763,7 @@ game_type_changed_cb (AisleriotGame *game,
   games_clock_reset (GAMES_CLOCK (priv->clock));
 
   gtk_statusbar_pop (priv->statusbar, priv->game_message_id);
+  gtk_statusbar_pop (priv->statusbar, priv->board_message_id);
 
   show_scores = (features & FEATURE_SCORE_HIDDEN) == 0;
   g_object_set (priv->score_box, "visible", show_scores, NULL);
@@ -1801,6 +1790,7 @@ game_new_cb (AisleriotGame *game,
   games_clock_reset (GAMES_CLOCK (priv->clock));
 
   gtk_statusbar_pop (priv->statusbar, priv->game_message_id);
+  gtk_statusbar_pop (priv->statusbar, priv->board_message_id);
 #endif /* HAVE_HILDON */
 }
 
@@ -1868,6 +1858,13 @@ game_exception_response_cb (GtkWidget *dialog,
       "--appname", "aisleriot",
       "--pid", pidstr,
       "--include", (const char *) error_file,
+#if GLIB_CHECK_VERSION (2, 20, 0)
+      /* This option was added to bug-buddy 2.25.x (bug 540150). We use the
+       * 2.26 glib version as a proxy to detect this, since there's no good
+       * other way.
+       */
+      "--unlink-tempfile",
+#endif
       NULL
     };
 
@@ -2045,6 +2042,24 @@ aisleriot_window_set_freecell_mode (AisleriotWindow *window,
   }
 }
 
+#ifndef HAVE_HILDON
+
+static void
+board_status_message_cb (AisleriotBoard *board,
+                         const char *status_message,
+                         AisleriotWindow *window)
+{
+  AisleriotWindowPrivate *priv = window->priv;
+
+  gtk_statusbar_pop (priv->statusbar, priv->board_message_id);
+
+  if (status_message != NULL) {
+    gtk_statusbar_push (priv->statusbar, priv->board_message_id, status_message);
+  }
+}
+
+#endif /* !HAVE_HILDON */
+
 #ifdef HAVE_CLUTTER
 
 static void
@@ -2103,7 +2118,7 @@ aisleriot_window_style_set (GtkWidget *widget,
     return;
 
   font_options = gdk_screen_get_font_options (gtk_widget_get_screen (widget));
-  games_card_theme_set_font_options (priv->theme, font_options);
+  ar_card_theme_set_font_options (priv->theme, font_options);
 
   /* FIXMEchpe: clear the cached cards in the slots?? */
 }
@@ -2165,9 +2180,17 @@ aisleriot_window_state_event (GtkWidget *widget,
 #ifdef HAVE_HILDON
 /* We never show tooltips, no need to put them into the binary */
 #define ACTION_TOOLTIP(string)  (NULL)
-#define ACTION_ACCEL(string1,string2) (string2)
 #else
 #define ACTION_TOOLTIP(string)  (string)
+#endif
+
+/* The maemo5 device (N900) doesn't have these extra hardware keys,
+ * so we only re-define the accels for maemo[34]. The N900 does have
+ * a slide-out keyboard, so using the regular accels should work fine.
+ */
+#if defined(HAVE_HILDON) && (defined(HAVE_MAEMO_3) || defined(HAVE_MAEMO_4))
+#define ACTION_ACCEL(string1,string2) (string2)
+#else
 #define ACTION_ACCEL(string1,string2) (string1)
 #endif
 
@@ -2195,7 +2218,7 @@ aisleriot_window_init (AisleriotWindow *window)
       ACTION_TOOLTIP (N_("Play a different game")),
       G_CALLBACK (select_game_cb) },
     { "RecentMenu", NULL, N_("_Recently Played") },
-    { "Statistics", GTK_STOCK_ADD, N_("S_tatistics"), NULL,
+    { "Statistics", NULL, N_("S_tatistics"), NULL,
       ACTION_TOOLTIP (N_("Show gameplay statistics")),
       G_CALLBACK (statistics_cb) },
     { "CloseWindow", GTK_STOCK_CLOSE, NULL, NULL,
@@ -2261,6 +2284,8 @@ aisleriot_window_init (AisleriotWindow *window)
     { "DebugGamePrev", GTK_STOCK_GO_BACK, NULL, NULL, NULL,
       G_CALLBACK (debug_game_prev) },
 #endif /* !HAVE_HILDON */
+    { "DebugTweakStyle", NULL, "_Tweak Style", NULL, NULL,
+      G_CALLBACK (debug_tweak_cb) },
 #endif /* ENABLE_DEBUG_UI */
 
     /* Accel actions */
@@ -2302,11 +2327,6 @@ aisleriot_window_init (AisleriotWindow *window)
       G_CALLBACK (animations_toggle_cb),
       FALSE /* not active by default */ },
 #endif /* HAVE_CLUTTER */
-#if defined(ENABLE_DEBUG_UI) && !defined(HAVE_CLUTTER)
-    { "DebugPixbufDrawing", NULL, "_Pixbuf drawing", NULL, NULL,
-      G_CALLBACK (debug_pixbuf_drawing_cb),
-      FALSE },
-#endif /* ENABLE_DEBUG_UI */
   };
 
   static const char names[][16] = {
@@ -2366,9 +2386,7 @@ aisleriot_window_init (AisleriotWindow *window)
 #ifdef ENABLE_DEBUG_UI
         "<menu action='DebugMenu'>"
           "<menuitem action='DebugChooseSeed'/>"
-#ifndef HAVE_CLUTTER
-          "<menuitem action='DebugPixbufDrawing'/>"
-#endif /* !HAVE_CLUTTER */
+          "<menuitem action='DebugTweakStyle'/>"
         "</menu>"
 #endif /* ENABLE_DEBUG_UI */
         "<menuitem action='CloseWindow'/>"
@@ -2419,7 +2437,7 @@ aisleriot_window_init (AisleriotWindow *window)
         "</menu>"
 #ifdef ENABLE_DEBUG_UI
         "<menu action='DebugMenu'>"
-          "<menuitem action='DebugPixbufDrawing'/>"
+          "<menuitem action='DebugTweakStyle'/>"
           "<separator/>"
           "<menuitem action='DebugChooseSeed'/>"
           "<menuitem action='DebugMoveNextScreen'/>"
@@ -2469,7 +2487,7 @@ aisleriot_window_init (AisleriotWindow *window)
   GtkAccelGroup *accel_group;
   GtkAction *action;
   char *theme_name;
-  GamesCardTheme *theme;
+  ArCardTheme *theme;
   guint i;
 #ifndef HAVE_HILDON
   GtkStatusbar *statusbar;
@@ -2487,34 +2505,11 @@ aisleriot_window_init (AisleriotWindow *window)
 
   priv->game = aisleriot_game_new ();
 
-#ifndef HAVE_CLUTTER
+  priv->theme_manager = ar_card_themes_new ();
 
-#ifdef HAVE_HILDON
-  priv->use_pixbuf_drawing = FALSE;
-#else
-{
-  const char *env;
-
-  env = g_getenv ("AISLERIOT_PIXBUF_DRAWING");
-
-  /* Default to pixbuf drawing */
-  priv->use_pixbuf_drawing = env == NULL || g_ascii_strtoull (env, NULL, 10) != 0;
-}
-#endif /* HAVE_HILDON */
-
-#ifdef GNOME_ENABLE_DEBUG
-  if (priv->use_pixbuf_drawing)
-    g_print ("Using pixbuf drawing method\n");
-  else
-    g_print ("Using pixmap drawing method\n");
-#endif /* GNOME_ENABLE_DEBUG */
-
-#endif /* !HAVE_CLUTTER */
-
-  priv->theme_manager = games_card_themes_new ();
+  priv->board_style = ar_style_new ();
 
 #ifdef HAVE_CLUTTER
-  priv->board_style = ar_style_new ();
   priv->board = ar_clutter_embed_new (priv->board_style);
 
   priv->baize_actor = aisleriot_baize_new ();
@@ -2540,17 +2535,15 @@ aisleriot_window_init (AisleriotWindow *window)
 
   /* FIXMEchpe: unref baize & board_actor here? */
 #else
-  priv->board = AISLERIOT_BOARD (aisleriot_board_new (priv->game));
-
-  aisleriot_board_set_pixbuf_drawing (priv->board, priv->use_pixbuf_drawing);
+  priv->board = AISLERIOT_BOARD (aisleriot_board_new (priv->board_style, priv->game));
 #endif /* HAVE_CLUTTER */
 
   theme_name = games_conf_get_string (NULL, aisleriot_conf_get_key (CONF_THEME), NULL);
-  theme = games_card_themes_get_theme_by_name (priv->theme_manager, theme_name);
+  theme = ar_card_themes_get_theme_by_name (priv->theme_manager, theme_name);
   g_free (theme_name);
   if (!theme) {
     /* Last-ditch fallback: try getting *any* theme */
-    theme = games_card_themes_get_theme_any (priv->theme_manager);
+    theme = ar_card_themes_get_theme_any (priv->theme_manager);
   }
   if (theme) {
     aisleriot_window_take_card_theme (window, theme /* adopts */);
@@ -2593,6 +2586,16 @@ aisleriot_window_init (AisleriotWindow *window)
   games_stock_prepare_for_statusbar_tooltips (priv->ui_manager,
                                               GTK_WIDGET (priv->statusbar));
 
+  priv->game_message_id = gtk_statusbar_get_context_id (priv->statusbar, "board-message");
+
+#ifdef HAVE_CLUTTER
+  g_signal_connect (priv->board_actor, "status-message",
+                    G_CALLBACK (board_status_message_cb), window);
+#else
+  g_signal_connect (priv->board, "status-message",
+                    G_CALLBACK (board_status_message_cb), window);
+#endif
+
 #if GTK_CHECK_VERSION (2, 11, 0)
   gtk_statusbar_set_has_resize_grip (priv->statusbar, TRUE);
 #else
@@ -2704,7 +2707,7 @@ aisleriot_window_init (AisleriotWindow *window)
    * if the theme loading above involved the fallback); in that case
    * we need to update the menu right now.
    */
-  if (games_card_themes_get_themes_loaded (priv->theme_manager))
+  if (ar_card_themes_get_themes_loaded (priv->theme_manager))
     install_card_theme_menu (priv->theme_manager, window);
 
   /* Rebuild the themes menu when the themes list changes */
@@ -2745,7 +2748,7 @@ aisleriot_window_init (AisleriotWindow *window)
 
 #ifdef ENABLE_CARD_THEMES_INSTALLER
   action = gtk_action_group_get_action (priv->action_group, "InstallThemes");
-  gtk_action_set_sensitive (action, games_card_themes_can_install_themes (priv->theme_manager));
+  gtk_action_set_sensitive (action, ar_card_themes_can_install_themes (priv->theme_manager));
 #endif /* ENABLE_CARD_THEMES_INSTALLER */
 
   set_fullscreen_actions (window, FALSE);
@@ -2836,11 +2839,6 @@ aisleriot_window_init (AisleriotWindow *window)
   g_signal_connect (window, "notify::is-topmost",
                     G_CALLBACK (sync_window_topmost_cb), NULL);
 #endif
-
-#if defined(ENABLE_DEBUG_UI) && !defined(HAVE_CLUTTER)
-  action = gtk_action_group_get_action (priv->action_group, "DebugPixbufDrawing");
-  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), priv->use_pixbuf_drawing);
-#endif /* ENABLE_DEBUG_UI && !HAVE_CLUTTER */
 }
 
 static void
@@ -3055,11 +3053,7 @@ free_load_idle_data (LoadIdleData *data)
   data->window->priv->load_idle_id = 0;
 
   g_free (data->game_file);
-#if GLIB_CHECK_VERSION (2, 10, 0)
   g_slice_free (LoadIdleData, data);
-#else
-  g_free (data);
-#endif
 }
 
 /**
@@ -3085,12 +3079,7 @@ aisleriot_window_set_game (AisleriotWindow *window,
     g_source_remove (priv->load_idle_id);
   }
 
-#if GLIB_CHECK_VERSION (2, 10, 0)
   data = g_slice_new (LoadIdleData);
-#else
-  data = g_new (LoadIdleData, 1);
-#endif
-
   data->window = window;
   data->game_file = g_strdup (game_file);
   data->seed = seed;
