@@ -21,7 +21,7 @@ import saver
 import sudoku_generator_gui
 import sudoku_maker
 import timer
-from defaults import (APPNAME, APPNAME_SHORT, AUTHORS, COPYRIGHT, DESCRIPTION,
+from defaults import (APPNAME, APPNAME_SHORT, AUTHORS, COPYRIGHT, DESCRIPTION, DOMAIN, 
         IMAGE_DIR, LICENSE, MIN_NEW_PUZZLES, UI_DIR, VERSION, WEBSITE, WEBSITE_LABEL)
 from gtk_goodies import gconf_wrapper, Undo, dialog_extras
 from simple_debug import simple_debug, options
@@ -384,13 +384,16 @@ class UI (gconf_wrapper.GConfWrapper):
     @simple_debug
     def start_worker_thread (self, *args):
         n_new_puzzles = self.sudoku_maker.n_puzzles(new = True)
-        if n_new_puzzles < self.gconf['minimum_number_of_new_puzzles']:
-            self.worker = threading.Thread(target = lambda *args: self.sudoku_maker.work(limit = 5))
-            self.worker_connections = [
-                self.timer.connect('timing-started', self.sudoku_maker.resume),
-                self.timer.connect('timing-stopped', self.sudoku_maker.pause)
-                ]
-            self.worker.start()
+        try:
+            if n_new_puzzles < self.gconf['minimum_number_of_new_puzzles']:
+                self.worker = threading.Thread(target = lambda *args: self.sudoku_maker.work(limit = 5))
+                self.worker_connections = [
+                    self.timer.connect('timing-started', self.sudoku_maker.resume),
+                    self.timer.connect('timing-stopped', self.sudoku_maker.pause)
+                    ]
+                self.worker.start()
+        except gconf_wrapper.GConfError:
+            pass # assume we have enough new puzzles
         return True
 
     @simple_debug
@@ -746,6 +749,7 @@ class TrackerBox (gtk.VBox):
 
         gtk.VBox.__init__(self)
         self.builder = gtk.Builder()
+        self.builder.set_translation_domain(DOMAIN)
         self.builder.add_from_file(os.path.join(UI_DIR, 'tracker.ui'))
         self.main_ui = main_ui
         self.vb = self.builder.get_object('vbox1')
