@@ -26,9 +26,12 @@
 
 #include <time.h>
 
-#include "games-setgid-io.h"
 #include "games-score.h"
 
+#ifdef ENABLE_SETGID
+#include "games-setgid-io.h"
+#endif
+
 G_BEGIN_DECLS
 
 #define GAMES_TYPE_SCORES_BACKEND (games_scores_backend_get_type ())
